package ru.gravit.launchserver.websocket.json.update;

import io.netty.channel.ChannelHandlerContext;
import ru.gravit.launcher.events.request.ErrorRequestEvent;
import ru.gravit.launcher.events.request.UpdateRequestEvent;
import ru.gravit.launcher.hasher.HashedDir;
import ru.gravit.launcher.profiles.ClientProfile;
import ru.gravit.launcher.serialize.signed.SignedObjectHolder;
import ru.gravit.launchserver.LaunchServer;
import ru.gravit.launchserver.socket.Client;
import ru.gravit.launchserver.websocket.WebSocketService;
import ru.gravit.launchserver.websocket.json.JsonResponseInterface;

public class UpdateResponse implements JsonResponseInterface {
    public String dirName;

    @Override
    public String getType() {
        return "update";
    }

    @Override
    public void execute(WebSocketService service, ChannelHandlerContext ctx, Client client) throws Exception {
        if (!client.isAuth || client.type != Client.Type.USER || client.profile == null) {
            service.sendObject(ctx, new ErrorRequestEvent("Access denied"));
            return;
        }
        if (!client.permissions.canAdmin) {
            for (ClientProfile p : LaunchServer.server.getProfiles()) {
                if (!client.profile.getTitle().equals(p.getTitle())) continue;
                if (!p.isWhitelistContains(client.username)) {
                    service.sendObject(ctx, new ErrorRequestEvent("You don't download this folder"));
                    return;
                }
            }
        }
        SignedObjectHolder<HashedDir> dir = LaunchServer.server.updatesDirMap.get(dirName);
        if(dir == null)
        {
            service.sendObject(ctx, new ErrorRequestEvent(String.format("Directory %s not found", dirName)));
            return;
        }
        service.sendObject(ctx, new UpdateRequestEvent(dir.object, LaunchServer.server.config.netty.downloadURL.replace("%dirname%",dirName)));
    }
}
